ospfd: Make ospf_if_lookup_recv_if() find the right unnumbered i/f

This function will return the interface for the first matching
remote address for PtP i/f's. That won't work for multiple
unnumbered i/f's as these may all have the same address.

Pass in the struct interface pointer, ifp, to find the
correct set of oi's to search in. This also reduces the
size of the search list, making it faster.

* ospfd/ospf_interface.c: Add struct interface * param to
  ospf_if_lookup_recv_if() to select the right list to search in.
* ospfd/ospf_interface.h: ditto.
* ospfd/ospf_packet.c: Pass new ifp argument to ospf_if_lookup_recv_if()
diff --git a/ospfd/ospf_interface.c b/ospfd/ospf_interface.c
index 4eccee7..afe3acf 100644
--- a/ospfd/ospf_interface.c
+++ b/ospfd/ospf_interface.c
@@ -439,11 +439,12 @@
   return NULL;
 }
 
 /* determine receiving interface by source of packet */
 struct ospf_interface *
-ospf_if_lookup_recv_if (struct ospf *ospf, struct in_addr src)
+ospf_if_lookup_recv_if (struct ospf *ospf, struct in_addr src,
+			struct interface *ifp)
 {
-  struct listnode *node;
+  struct route_node *rn;
   struct prefix_ipv4 addr;
   struct ospf_interface *oi, *match;
 
@@ -453,11 +454,16 @@
 
   match = NULL;
 
-  for (ALL_LIST_ELEMENTS_RO (ospf->oiflist, node, oi))
+  for (rn = route_top (IF_OIFS (ifp)); rn; rn = route_next (rn))
     {
+      oi = rn->info;
+
+      if (!oi) /* oi can be NULL for PtP aliases */
+	continue;
+
       if (oi->type == OSPF_IFTYPE_VIRTUALLINK)
 	continue;
-      
+
       if (if_is_loopback (oi->ifp))
         continue;
@@ -439,11 +439,12 @@
 }
 
-/* determine receiving interface by source of packet */
+/* determine receiving interface by ifp and source address */
 struct ospf_interface *